@@ -164,7 +164,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
         if is_lyric_ver2 and (comp.type == "lyric" or comp.type == "mix_lyric"):
             audio_compilation_path = comp.get_audio()
             lyric_comp = comp
-            if deezer_artist_id and deezer_artist_id.isnumeric() and int(deezer_artist_id) < 907996688:
+            if deezer_artist_id and f"{deezer_artist_id}".isnumeric() and int(deezer_artist_id) < 907996688:
                 audio_compilation_path = MusicHelper.create_lyric_outro_songs(deezer_artist_id, lyric_outro_repeat, outro_claim_topic,
                                                                audio_compilation_path)
             continue
@@ -592,10 +592,17 @@ class VideoComp(Component):
             self.isSmoothLoop = False
         if self.isLoop and self.isSmoothLoop and self.ext != "gif" and not self.is_intro and not self.is_outro and self.md5 != "tiktok":
             obj = requests.get(self.mf_server+"resource/get-md5/"+self.kind+"/"+self.md5).json()
+            is_loop_mk=False
             if "id" in obj:
                 if "loop_link" in obj and obj['loop_link'] is not None and "gdrive" in obj['loop_link']:
-                    self.video_path = download_file(obj['loop_link'], ext=self.ext)
+                    try:
+                        self.video_path = download_file(obj['loop_link'], ext=self.ext)
+                    except:
+                        is_loop_mk = True
+                        pass
                 else:
+                    is_loop_mk = True
+                if is_loop_mk:
                     self.video_path = download_file(self.video_url, ext=self.ext)
                     path_loop = create_suource_can_loop_path(self.video_path, True, ext=self.ext)
                     if path_loop is None:
